==> zio-aws-ec2_2.13-5.17.126.1-sources.jar: zio/aws/ec2/model/CreateTransitGatewayConnectResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayConnectResponse(
    transitGatewayConnect: Option[zio.aws.ec2.model.TransitGatewayConnect] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse = {
    import CreateTransitGatewayConnectResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
      .builder()
      .optionallyWith(
        transitGatewayConnect.map(value => value.buildAwsValue())
      )(_.transitGatewayConnect)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayConnectResponse.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayConnectResponse.wrap(buildAwsValue())
}
object CreateTransitGatewayConnectResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateTransitGatewayConnectResponse =
      zio.aws.ec2.model.CreateTransitGatewayConnectResponse(
        transitGatewayConnect.map(value => value.asEditable)
      )
    def transitGatewayConnect
        : Option[zio.aws.ec2.model.TransitGatewayConnect.ReadOnly]
    def getTransitGatewayConnect
        : ZIO[Any, AwsError, zio.aws.ec2.model.TransitGatewayConnect.ReadOnly] =
      AwsError.unwrapOptionField("transitGatewayConnect", transitGatewayConnect)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
  ) extends zio.aws.ec2.model.CreateTransitGatewayConnectResponse.ReadOnly {
    override val transitGatewayConnect
        : Option[zio.aws.ec2.model.TransitGatewayConnect.ReadOnly] = scala
      .Option(impl.transitGatewayConnect())
      .map(value => zio.aws.ec2.model.TransitGatewayConnect.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
  ): zio.aws.ec2.model.CreateTransitGatewayConnectResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.19.17.1-sources.jar: zio/aws/ec2/model/CreateTransitGatewayConnectResponse.scala <==
package zio.aws.ec2.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateTransitGatewayConnectResponse(
    transitGatewayConnect: Optional[zio.aws.ec2.model.TransitGatewayConnect] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse = {
    import CreateTransitGatewayConnectResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
      .builder()
      .optionallyWith(
        transitGatewayConnect.map(value => value.buildAwsValue())
      )(_.transitGatewayConnect)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.CreateTransitGatewayConnectResponse.ReadOnly =
    zio.aws.ec2.model.CreateTransitGatewayConnectResponse.wrap(buildAwsValue())
}
object CreateTransitGatewayConnectResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.CreateTransitGatewayConnectResponse =
      zio.aws.ec2.model.CreateTransitGatewayConnectResponse(
        transitGatewayConnect.map(value => value.asEditable)
      )
    def transitGatewayConnect
        : Optional[zio.aws.ec2.model.TransitGatewayConnect.ReadOnly]
    def getTransitGatewayConnect
        : ZIO[Any, AwsError, zio.aws.ec2.model.TransitGatewayConnect.ReadOnly] =
      AwsError.unwrapOptionField("transitGatewayConnect", transitGatewayConnect)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
  ) extends zio.aws.ec2.model.CreateTransitGatewayConnectResponse.ReadOnly {
    override val transitGatewayConnect
        : Optional[zio.aws.ec2.model.TransitGatewayConnect.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.transitGatewayConnect())
        .map(value => zio.aws.ec2.model.TransitGatewayConnect.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.CreateTransitGatewayConnectResponse
  ): zio.aws.ec2.model.CreateTransitGatewayConnectResponse.ReadOnly =
    new Wrapper(impl)
}
